CREATE TABLE person (
	nummer		INTEGER PRIMARY KEY, 
	vorname		VARCHAR(30), 
	nachname	VARCHAR(30));
	
CREATE TABLE mitarbeiter(
	nummer		INTEGER PRIMARY KEY REFERENCES Person,
	einstellungsdatum	DATE);
	
CREATE TABLE kuendigung (
	nummer		INTEGER PRIMARY KEY REFERENCES Mitarbeiter, 
	kuendigungsdatum	DATE);
	
CREATE TABLE kuenstler (
	nummer		INTEGER PRIMARY KEY REFERENCES Person, 
	bekanntheit	INTEGER,
	CHECK (bekanntheit between 0 and 10)); 
	
CREATE TABLE produkt (
	nummer		INTEGER PRIMARY KEY, 
	bezeichnung	VARCHAR(100), 
	gewicht		INTEGER);
	
CREATE TABLE standardsortiment (
	nummer		INTEGER PRIMARY KEY REFERENCES Produkt,
	preis		NUMERIC(7,2), 
	verpackung	VARCHAR(100));
	
CREATE TABLE kunstwerk (
	nummer		INTEGER PRIMARY KEY REFERENCES Produkt,
	schaetzwert	NUMERIC(10,2));
	
CREATE TABLE maschine (
	nummer		INTEGER PRIMARY KEY, 
	beschreibung	VARCHAR(30));
	
CREATE TABLE bedient (
	mitnummer	INTEGER REFERENCES Mitarbeiter(nummer), 
	maschnummer	INTEGER REFERENCES Maschine (nummer),
	PRIMARY KEY (mitnummer, maschnummer));
	
CREATE TABLE erzeugt (
	maschnummer	INTEGER REFERENCES Maschine (nummer), 
	pnummer		INTEGER REFERENCES Produkt (nummer),
	PRIMARY KEY (maschnummer, pnummer));
	
CREATE TABLE lager (
	bezeichnung	VARCHAR(30) PRIMARY KEY, 
	flaeche		NUMERIC(10,2));
	
CREATE TABLE betreut(
	mitnummer	INTEGER PRIMARY KEY REFERENCES Mitarbeiter (nummer), 
	bezeichnung 	VARCHAR(30) REFERENCES Lager);
	
CREATE TABLE lagert (
	bezeichnung	VARCHAR(30) REFERENCES Lager, 
	pnummer		INTEGER REFERENCES Produkt (nummer), 
	menge		INTEGER,
	PRIMARY KEY (bezeichnung, pnummer));
	
CREATE TABLE kunde (
	firmenname	VARCHAR(30) PRIMARY KEY, 
	adresse		VARCHAR(60), 
	telefonnummer	VARCHAR(20));
	
CREATE TABLE auftrag (
	firmenname	VARCHAR(50), 
	nummer		INTEGER, 
	datum		DATE, 
	status		VARCHAR(50),
	PRIMARY KEY (firmenname, nummer)); 
	
CREATE TABLE enthaelt (
	firmenname	VARCHAR(30), 
	nummer		INTEGER, 
	pnummer		INTEGER REFERENCES Produkt (nummer), 
	menge		INTEGER,
	FOREIGN KEY (firmenname, nummer) REFERENCES Auftrag,
	PRIMARY KEY (firmenname, nummer, pnummer)); 
	
CREATE TABLE kunstschau (
	datum		DATE, 
	name		VARCHAR(100), 
	ort		VARCHAR(40), 
	land		VARCHAR(40),
	PRIMARY KEY (datum, name)); 

CREATE TABLE zeigt (
	knummer 	INTEGER REFERENCES Kuenstler (nummer), 
	kunstwerknummer	INTEGER REFERENCES Kunstwerk (nummer), 
	datum		DATE, 
	name		VARCHAR(100),
	platz		INTEGER,
	FOREIGN KEY (datum, name) REFERENCES Kunstschau,
	PRIMARY KEY (knummer, kunstwerknummer, datum, name)); 








